ngff_zarr.config - ngff-zarr
Description: Module Contents: Classes:,, NgffZarrConfig,,,,, Functions:,, default_store_factory,,,,, Data:,, config,,,,, API:

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Edit this page
Toggle table of contents sidebar

# `ngff_zarr.config`

## Module Contents

### Classes

`NgffZarrConfig` |

### Functions

`default_store_factory` |

### Data

`config` |

### API

ngff_zarr.config.default_store_factory()

class ngff_zarr.config.NgffZarrConfig
  memory_target: int

    None

  task_target: int

    50000

  cache_store: zarr.storage.StoreLike

    ‘field(…)’

ngff_zarr.config.config

  ‘NgffZarrConfig(…)’